@@ -1,5 +1,5 @@
 package Unicode::CheckUTF8::PP;
-$Unicode::CheckUTF8::PP::VERSION = '0.002';
+$Unicode::CheckUTF8::PP::VERSION = '0.003';
 use base qw(Exporter);
 # ABSTRACT: Pure Perl implementation of Unicode::CheckUTF8
 
@@ -96,7 +96,7 @@ my $_isLegalUTF8String = sub {
        $i += $length;
     }
 
-    return (@bytes && $l && $l == $bytes[-1]) ? 1 : 0;
+    return ($l || 0) == ($bytes[-1] || 0) ? 1 : 0;
 };
 
 sub is_utf8 {
@@ -117,7 +117,7 @@ Unicode::CheckUTF8::PP - Pure Perl implementation of Unicode::CheckUTF8
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
